
onnxcustom: deploy machine learned models
=========================================

.. image:: https://circleci.com/gh/sdpython/onnxcustom/tree/master.svg?style=svg
    :target: https://circleci.com/gh/sdpython/onnxcustom/tree/master

.. image:: https://travis-ci.org/sdpython/onnxcustom.svg?branch=master
    :target: https://travis-ci.org/sdpython/onnxcustom
    :alt: Build status

.. image:: https://ci.appveyor.com/api/projects/status/a3sn45a2fayoxb5q?svg=true
    :target: https://ci.appveyor.com/project/sdpython/onnxcustom
    :alt: Build Status Windows

.. image:: https://codecov.io/gh/sdpython/onnxcustom/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/sdpython/onnxcustom

.. image:: https://badge.fury.io/py/onnxcustom.svg
    :target: http://badge.fury.io/py/onnxcustom

.. image:: http://img.shields.io/github/issues/sdpython/onnxcustom.png
    :alt: GitHub Issues
    :target: https://github.com/sdpython/onnxcustom/issues

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: MIT License
    :target: http://opensource.org/licenses/MIT

.. image:: https://img.shields.io/github/repo-size/sdpython/onnxcustom
    :target: https://github.com/sdpython/onnxcustom/
    :alt: size

This project leverages :epkg:`ONNX` to deploy pipelines,
standard pipeline and pipeline including custom pieces.
It shows how to create a custom converter, needing custom
operators.


.. toctree::
    :maxdepth: 1

    tutorial
    doc
    api
    auto_examples/index
    dev
    versions

Sources available on
`github/onnxcustom <https://github.com/sdpython/onnxcustom>`_.

*Indices and tables*

* :ref:`genindex`
* `Code coverage <coverage.html>`_
